# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class Externalv1CloudSpaceInstanceStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_url': 'str',
        'cloud_space_instance_id': 'str',
        'compute_config': 'V1UserRequestedComputeConfig',
        'creation_timestamp': 'datetime',
        'data_connection_mounts': 'list[V1DataConnectionMount]',
        'free': 'bool',
        'ide': 'str',
        'instance_id': 'str',
        'instance_region': 'str',
        'jupyterlab_url': 'str',
        'phase': 'V1CloudSpaceInstanceState',
        'ssh_host': 'str',
        'ssh_port': 'int',
        'ssh_username': 'str',
        'start_timestamp': 'datetime',
        'startup_eta_seconds': 'str',
        'startup_percentage': 'str',
        'startup_phase': 'str',
        'startup_status': 'V1CloudSpaceInstanceStartupStatus',
        'status_message': 'str',
        'sync_eta_seconds': 'str',
        'sync_in_progress': 'bool',
        'sync_percentage': 'str',
        'vscode_url': 'str'
    }

    attribute_map = {
        'app_url': 'appUrl',
        'cloud_space_instance_id': 'cloudSpaceInstanceId',
        'compute_config': 'computeConfig',
        'creation_timestamp': 'creationTimestamp',
        'data_connection_mounts': 'dataConnectionMounts',
        'free': 'free',
        'ide': 'ide',
        'instance_id': 'instanceId',
        'instance_region': 'instanceRegion',
        'jupyterlab_url': 'jupyterlabUrl',
        'phase': 'phase',
        'ssh_host': 'sshHost',
        'ssh_port': 'sshPort',
        'ssh_username': 'sshUsername',
        'start_timestamp': 'startTimestamp',
        'startup_eta_seconds': 'startupEtaSeconds',
        'startup_percentage': 'startupPercentage',
        'startup_phase': 'startupPhase',
        'startup_status': 'startupStatus',
        'status_message': 'statusMessage',
        'sync_eta_seconds': 'syncEtaSeconds',
        'sync_in_progress': 'syncInProgress',
        'sync_percentage': 'syncPercentage',
        'vscode_url': 'vscodeUrl'
    }

    def __init__(self, app_url: 'str' =None, cloud_space_instance_id: 'str' =None, compute_config: 'V1UserRequestedComputeConfig' =None, creation_timestamp: 'datetime' =None, data_connection_mounts: 'list[V1DataConnectionMount]' =None, free: 'bool' =None, ide: 'str' =None, instance_id: 'str' =None, instance_region: 'str' =None, jupyterlab_url: 'str' =None, phase: 'V1CloudSpaceInstanceState' =None, ssh_host: 'str' =None, ssh_port: 'int' =None, ssh_username: 'str' =None, start_timestamp: 'datetime' =None, startup_eta_seconds: 'str' =None, startup_percentage: 'str' =None, startup_phase: 'str' =None, startup_status: 'V1CloudSpaceInstanceStartupStatus' =None, status_message: 'str' =None, sync_eta_seconds: 'str' =None, sync_in_progress: 'bool' =None, sync_percentage: 'str' =None, vscode_url: 'str' =None):  # noqa: E501
        """Externalv1CloudSpaceInstanceStatus - a model defined in Swagger"""  # noqa: E501
        self._app_url = None
        self._cloud_space_instance_id = None
        self._compute_config = None
        self._creation_timestamp = None
        self._data_connection_mounts = None
        self._free = None
        self._ide = None
        self._instance_id = None
        self._instance_region = None
        self._jupyterlab_url = None
        self._phase = None
        self._ssh_host = None
        self._ssh_port = None
        self._ssh_username = None
        self._start_timestamp = None
        self._startup_eta_seconds = None
        self._startup_percentage = None
        self._startup_phase = None
        self._startup_status = None
        self._status_message = None
        self._sync_eta_seconds = None
        self._sync_in_progress = None
        self._sync_percentage = None
        self._vscode_url = None
        self.discriminator = None
        if app_url is not None:
            self.app_url = app_url
        if cloud_space_instance_id is not None:
            self.cloud_space_instance_id = cloud_space_instance_id
        if compute_config is not None:
            self.compute_config = compute_config
        if creation_timestamp is not None:
            self.creation_timestamp = creation_timestamp
        if data_connection_mounts is not None:
            self.data_connection_mounts = data_connection_mounts
        if free is not None:
            self.free = free
        if ide is not None:
            self.ide = ide
        if instance_id is not None:
            self.instance_id = instance_id
        if instance_region is not None:
            self.instance_region = instance_region
        if jupyterlab_url is not None:
            self.jupyterlab_url = jupyterlab_url
        if phase is not None:
            self.phase = phase
        if ssh_host is not None:
            self.ssh_host = ssh_host
        if ssh_port is not None:
            self.ssh_port = ssh_port
        if ssh_username is not None:
            self.ssh_username = ssh_username
        if start_timestamp is not None:
            self.start_timestamp = start_timestamp
        if startup_eta_seconds is not None:
            self.startup_eta_seconds = startup_eta_seconds
        if startup_percentage is not None:
            self.startup_percentage = startup_percentage
        if startup_phase is not None:
            self.startup_phase = startup_phase
        if startup_status is not None:
            self.startup_status = startup_status
        if status_message is not None:
            self.status_message = status_message
        if sync_eta_seconds is not None:
            self.sync_eta_seconds = sync_eta_seconds
        if sync_in_progress is not None:
            self.sync_in_progress = sync_in_progress
        if sync_percentage is not None:
            self.sync_percentage = sync_percentage
        if vscode_url is not None:
            self.vscode_url = vscode_url

    @property
    def app_url(self) -> 'str':
        """Gets the app_url of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The app_url of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._app_url

    @app_url.setter
    def app_url(self, app_url: 'str'):
        """Sets the app_url of this Externalv1CloudSpaceInstanceStatus.


        :param app_url: The app_url of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._app_url = app_url

    @property
    def cloud_space_instance_id(self) -> 'str':
        """Gets the cloud_space_instance_id of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The cloud_space_instance_id of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._cloud_space_instance_id

    @cloud_space_instance_id.setter
    def cloud_space_instance_id(self, cloud_space_instance_id: 'str'):
        """Sets the cloud_space_instance_id of this Externalv1CloudSpaceInstanceStatus.


        :param cloud_space_instance_id: The cloud_space_instance_id of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._cloud_space_instance_id = cloud_space_instance_id

    @property
    def compute_config(self) -> 'V1UserRequestedComputeConfig':
        """Gets the compute_config of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The compute_config of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: V1UserRequestedComputeConfig
        """
        return self._compute_config

    @compute_config.setter
    def compute_config(self, compute_config: 'V1UserRequestedComputeConfig'):
        """Sets the compute_config of this Externalv1CloudSpaceInstanceStatus.


        :param compute_config: The compute_config of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: V1UserRequestedComputeConfig
        """

        self._compute_config = compute_config

    @property
    def creation_timestamp(self) -> 'datetime':
        """Gets the creation_timestamp of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The creation_timestamp of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_timestamp

    @creation_timestamp.setter
    def creation_timestamp(self, creation_timestamp: 'datetime'):
        """Sets the creation_timestamp of this Externalv1CloudSpaceInstanceStatus.


        :param creation_timestamp: The creation_timestamp of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: datetime
        """

        self._creation_timestamp = creation_timestamp

    @property
    def data_connection_mounts(self) -> 'list[V1DataConnectionMount]':
        """Gets the data_connection_mounts of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The data_connection_mounts of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: list[V1DataConnectionMount]
        """
        return self._data_connection_mounts

    @data_connection_mounts.setter
    def data_connection_mounts(self, data_connection_mounts: 'list[V1DataConnectionMount]'):
        """Sets the data_connection_mounts of this Externalv1CloudSpaceInstanceStatus.


        :param data_connection_mounts: The data_connection_mounts of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: list[V1DataConnectionMount]
        """

        self._data_connection_mounts = data_connection_mounts

    @property
    def free(self) -> 'bool':
        """Gets the free of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The free of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: bool
        """
        return self._free

    @free.setter
    def free(self, free: 'bool'):
        """Sets the free of this Externalv1CloudSpaceInstanceStatus.


        :param free: The free of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: bool
        """

        self._free = free

    @property
    def ide(self) -> 'str':
        """Gets the ide of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The ide of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._ide

    @ide.setter
    def ide(self, ide: 'str'):
        """Sets the ide of this Externalv1CloudSpaceInstanceStatus.


        :param ide: The ide of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._ide = ide

    @property
    def instance_id(self) -> 'str':
        """Gets the instance_id of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The instance_id of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id: 'str'):
        """Sets the instance_id of this Externalv1CloudSpaceInstanceStatus.


        :param instance_id: The instance_id of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def instance_region(self) -> 'str':
        """Gets the instance_region of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The instance_region of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._instance_region

    @instance_region.setter
    def instance_region(self, instance_region: 'str'):
        """Sets the instance_region of this Externalv1CloudSpaceInstanceStatus.


        :param instance_region: The instance_region of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._instance_region = instance_region

    @property
    def jupyterlab_url(self) -> 'str':
        """Gets the jupyterlab_url of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The jupyterlab_url of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._jupyterlab_url

    @jupyterlab_url.setter
    def jupyterlab_url(self, jupyterlab_url: 'str'):
        """Sets the jupyterlab_url of this Externalv1CloudSpaceInstanceStatus.


        :param jupyterlab_url: The jupyterlab_url of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._jupyterlab_url = jupyterlab_url

    @property
    def phase(self) -> 'V1CloudSpaceInstanceState':
        """Gets the phase of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The phase of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: V1CloudSpaceInstanceState
        """
        return self._phase

    @phase.setter
    def phase(self, phase: 'V1CloudSpaceInstanceState'):
        """Sets the phase of this Externalv1CloudSpaceInstanceStatus.


        :param phase: The phase of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: V1CloudSpaceInstanceState
        """

        self._phase = phase

    @property
    def ssh_host(self) -> 'str':
        """Gets the ssh_host of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The ssh_host of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._ssh_host

    @ssh_host.setter
    def ssh_host(self, ssh_host: 'str'):
        """Sets the ssh_host of this Externalv1CloudSpaceInstanceStatus.


        :param ssh_host: The ssh_host of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._ssh_host = ssh_host

    @property
    def ssh_port(self) -> 'int':
        """Gets the ssh_port of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The ssh_port of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: int
        """
        return self._ssh_port

    @ssh_port.setter
    def ssh_port(self, ssh_port: 'int'):
        """Sets the ssh_port of this Externalv1CloudSpaceInstanceStatus.


        :param ssh_port: The ssh_port of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: int
        """

        self._ssh_port = ssh_port

    @property
    def ssh_username(self) -> 'str':
        """Gets the ssh_username of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The ssh_username of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._ssh_username

    @ssh_username.setter
    def ssh_username(self, ssh_username: 'str'):
        """Sets the ssh_username of this Externalv1CloudSpaceInstanceStatus.


        :param ssh_username: The ssh_username of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._ssh_username = ssh_username

    @property
    def start_timestamp(self) -> 'datetime':
        """Gets the start_timestamp of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The start_timestamp of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._start_timestamp

    @start_timestamp.setter
    def start_timestamp(self, start_timestamp: 'datetime'):
        """Sets the start_timestamp of this Externalv1CloudSpaceInstanceStatus.


        :param start_timestamp: The start_timestamp of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: datetime
        """

        self._start_timestamp = start_timestamp

    @property
    def startup_eta_seconds(self) -> 'str':
        """Gets the startup_eta_seconds of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The startup_eta_seconds of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._startup_eta_seconds

    @startup_eta_seconds.setter
    def startup_eta_seconds(self, startup_eta_seconds: 'str'):
        """Sets the startup_eta_seconds of this Externalv1CloudSpaceInstanceStatus.


        :param startup_eta_seconds: The startup_eta_seconds of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._startup_eta_seconds = startup_eta_seconds

    @property
    def startup_percentage(self) -> 'str':
        """Gets the startup_percentage of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The startup_percentage of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._startup_percentage

    @startup_percentage.setter
    def startup_percentage(self, startup_percentage: 'str'):
        """Sets the startup_percentage of this Externalv1CloudSpaceInstanceStatus.


        :param startup_percentage: The startup_percentage of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._startup_percentage = startup_percentage

    @property
    def startup_phase(self) -> 'str':
        """Gets the startup_phase of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The startup_phase of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._startup_phase

    @startup_phase.setter
    def startup_phase(self, startup_phase: 'str'):
        """Sets the startup_phase of this Externalv1CloudSpaceInstanceStatus.


        :param startup_phase: The startup_phase of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._startup_phase = startup_phase

    @property
    def startup_status(self) -> 'V1CloudSpaceInstanceStartupStatus':
        """Gets the startup_status of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The startup_status of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: V1CloudSpaceInstanceStartupStatus
        """
        return self._startup_status

    @startup_status.setter
    def startup_status(self, startup_status: 'V1CloudSpaceInstanceStartupStatus'):
        """Sets the startup_status of this Externalv1CloudSpaceInstanceStatus.


        :param startup_status: The startup_status of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: V1CloudSpaceInstanceStartupStatus
        """

        self._startup_status = startup_status

    @property
    def status_message(self) -> 'str':
        """Gets the status_message of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The status_message of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message: 'str'):
        """Sets the status_message of this Externalv1CloudSpaceInstanceStatus.


        :param status_message: The status_message of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._status_message = status_message

    @property
    def sync_eta_seconds(self) -> 'str':
        """Gets the sync_eta_seconds of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The sync_eta_seconds of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._sync_eta_seconds

    @sync_eta_seconds.setter
    def sync_eta_seconds(self, sync_eta_seconds: 'str'):
        """Sets the sync_eta_seconds of this Externalv1CloudSpaceInstanceStatus.


        :param sync_eta_seconds: The sync_eta_seconds of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._sync_eta_seconds = sync_eta_seconds

    @property
    def sync_in_progress(self) -> 'bool':
        """Gets the sync_in_progress of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The sync_in_progress of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: bool
        """
        return self._sync_in_progress

    @sync_in_progress.setter
    def sync_in_progress(self, sync_in_progress: 'bool'):
        """Sets the sync_in_progress of this Externalv1CloudSpaceInstanceStatus.


        :param sync_in_progress: The sync_in_progress of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: bool
        """

        self._sync_in_progress = sync_in_progress

    @property
    def sync_percentage(self) -> 'str':
        """Gets the sync_percentage of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The sync_percentage of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._sync_percentage

    @sync_percentage.setter
    def sync_percentage(self, sync_percentage: 'str'):
        """Sets the sync_percentage of this Externalv1CloudSpaceInstanceStatus.


        :param sync_percentage: The sync_percentage of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._sync_percentage = sync_percentage

    @property
    def vscode_url(self) -> 'str':
        """Gets the vscode_url of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501


        :return: The vscode_url of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._vscode_url

    @vscode_url.setter
    def vscode_url(self, vscode_url: 'str'):
        """Sets the vscode_url of this Externalv1CloudSpaceInstanceStatus.


        :param vscode_url: The vscode_url of this Externalv1CloudSpaceInstanceStatus.  # noqa: E501
        :type: str
        """

        self._vscode_url = vscode_url

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Externalv1CloudSpaceInstanceStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'Externalv1CloudSpaceInstanceStatus') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, Externalv1CloudSpaceInstanceStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'Externalv1CloudSpaceInstanceStatus') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



import os
from pathlib import Path


def truthy(val) -> bool:
    if val in [
            "1",
            "true",
            "True",
            True,
    ]:
        return True
    if val in ["0", "false", "False", False, None]:
        return False

    return bool(val)


LIGHTNING_CLOUD_URL = os.getenv("LIGHTNING_CLOUD_URL", "https://lightning.ai")

SSL_CA_CERT = os.getenv("REQUESTS_CA_BUNDLE",
                        default=os.getenv("SSL_CERT_FILE", default=None))
VERSION = os.getenv("VERSION", "0.0.1")
DEBUG = truthy(os.getenv("DEBUG"))
CONTEXT = os.getenv("CONTEXT", "staging-3")
LIGHTNING_SETTINGS_PATH = os.getenv(
    'LIGHTNING_SETTINGS_PATH',
    str(Path.home() / '.lightning' / 'settings.json'))
LIGHTNING_CREDENTIAL_PATH = os.getenv(
    'LIGHTNING_CREDENTIAL_PATH',
    str(Path.home() / '.lightning' / 'credentials.json'))

DOT_IGNORE_FILENAME = ".lightningignore"

LEEWAY = 100
IS_DEV_ENV = True


def reset_global_variables() -> None:
    """ Reset the settings from env variables"""
    global DEBUG, CONTEXT, LIGHTNING_CLOUD_URL

    if 'DEBUG' in os.environ:
        DEBUG = truthy(os.environ['DEBUG'])

    if 'GRID_CLUSTER_ID' in os.environ:
        CONTEXT = os.environ['GRID_CLUSTER_ID']

    if 'GRID_URL' in os.environ:
        LIGHTNING_CLOUD_URL = os.environ['GRID_URL']



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1StudioJob(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app': 'V1StudioJobApp',
        'cloudspace_id': 'str',
        'command': 'str',
        'created_at': 'datetime',
        'id': 'str',
        'name': 'str',
        'port': 'str',
        'project_id': 'str',
        'terminal_session_id': 'str',
        'updated_at': 'datetime',
        'user_id': 'str'
    }

    attribute_map = {
        'app': 'app',
        'cloudspace_id': 'cloudspaceId',
        'command': 'command',
        'created_at': 'createdAt',
        'id': 'id',
        'name': 'name',
        'port': 'port',
        'project_id': 'projectId',
        'terminal_session_id': 'terminalSessionId',
        'updated_at': 'updatedAt',
        'user_id': 'userId'
    }

    def __init__(self, app: 'V1StudioJobApp' =None, cloudspace_id: 'str' =None, command: 'str' =None, created_at: 'datetime' =None, id: 'str' =None, name: 'str' =None, port: 'str' =None, project_id: 'str' =None, terminal_session_id: 'str' =None, updated_at: 'datetime' =None, user_id: 'str' =None):  # noqa: E501
        """V1StudioJob - a model defined in Swagger"""  # noqa: E501
        self._app = None
        self._cloudspace_id = None
        self._command = None
        self._created_at = None
        self._id = None
        self._name = None
        self._port = None
        self._project_id = None
        self._terminal_session_id = None
        self._updated_at = None
        self._user_id = None
        self.discriminator = None
        if app is not None:
            self.app = app
        if cloudspace_id is not None:
            self.cloudspace_id = cloudspace_id
        if command is not None:
            self.command = command
        if created_at is not None:
            self.created_at = created_at
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if port is not None:
            self.port = port
        if project_id is not None:
            self.project_id = project_id
        if terminal_session_id is not None:
            self.terminal_session_id = terminal_session_id
        if updated_at is not None:
            self.updated_at = updated_at
        if user_id is not None:
            self.user_id = user_id

    @property
    def app(self) -> 'V1StudioJobApp':
        """Gets the app of this V1StudioJob.  # noqa: E501


        :return: The app of this V1StudioJob.  # noqa: E501
        :rtype: V1StudioJobApp
        """
        return self._app

    @app.setter
    def app(self, app: 'V1StudioJobApp'):
        """Sets the app of this V1StudioJob.


        :param app: The app of this V1StudioJob.  # noqa: E501
        :type: V1StudioJobApp
        """

        self._app = app

    @property
    def cloudspace_id(self) -> 'str':
        """Gets the cloudspace_id of this V1StudioJob.  # noqa: E501


        :return: The cloudspace_id of this V1StudioJob.  # noqa: E501
        :rtype: str
        """
        return self._cloudspace_id

    @cloudspace_id.setter
    def cloudspace_id(self, cloudspace_id: 'str'):
        """Sets the cloudspace_id of this V1StudioJob.


        :param cloudspace_id: The cloudspace_id of this V1StudioJob.  # noqa: E501
        :type: str
        """

        self._cloudspace_id = cloudspace_id

    @property
    def command(self) -> 'str':
        """Gets the command of this V1StudioJob.  # noqa: E501


        :return: The command of this V1StudioJob.  # noqa: E501
        :rtype: str
        """
        return self._command

    @command.setter
    def command(self, command: 'str'):
        """Sets the command of this V1StudioJob.


        :param command: The command of this V1StudioJob.  # noqa: E501
        :type: str
        """

        self._command = command

    @property
    def created_at(self) -> 'datetime':
        """Gets the created_at of this V1StudioJob.  # noqa: E501


        :return: The created_at of this V1StudioJob.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at: 'datetime'):
        """Sets the created_at of this V1StudioJob.


        :param created_at: The created_at of this V1StudioJob.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def id(self) -> 'str':
        """Gets the id of this V1StudioJob.  # noqa: E501


        :return: The id of this V1StudioJob.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1StudioJob.


        :param id: The id of this V1StudioJob.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self) -> 'str':
        """Gets the name of this V1StudioJob.  # noqa: E501


        :return: The name of this V1StudioJob.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1StudioJob.


        :param name: The name of this V1StudioJob.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def port(self) -> 'str':
        """Gets the port of this V1StudioJob.  # noqa: E501


        :return: The port of this V1StudioJob.  # noqa: E501
        :rtype: str
        """
        return self._port

    @port.setter
    def port(self, port: 'str'):
        """Sets the port of this V1StudioJob.


        :param port: The port of this V1StudioJob.  # noqa: E501
        :type: str
        """

        self._port = port

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1StudioJob.  # noqa: E501


        :return: The project_id of this V1StudioJob.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1StudioJob.


        :param project_id: The project_id of this V1StudioJob.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def terminal_session_id(self) -> 'str':
        """Gets the terminal_session_id of this V1StudioJob.  # noqa: E501


        :return: The terminal_session_id of this V1StudioJob.  # noqa: E501
        :rtype: str
        """
        return self._terminal_session_id

    @terminal_session_id.setter
    def terminal_session_id(self, terminal_session_id: 'str'):
        """Sets the terminal_session_id of this V1StudioJob.


        :param terminal_session_id: The terminal_session_id of this V1StudioJob.  # noqa: E501
        :type: str
        """

        self._terminal_session_id = terminal_session_id

    @property
    def updated_at(self) -> 'datetime':
        """Gets the updated_at of this V1StudioJob.  # noqa: E501


        :return: The updated_at of this V1StudioJob.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at: 'datetime'):
        """Sets the updated_at of this V1StudioJob.


        :param updated_at: The updated_at of this V1StudioJob.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def user_id(self) -> 'str':
        """Gets the user_id of this V1StudioJob.  # noqa: E501


        :return: The user_id of this V1StudioJob.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: 'str'):
        """Sets the user_id of this V1StudioJob.


        :param user_id: The user_id of this V1StudioJob.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1StudioJob, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1StudioJob') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1StudioJob):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1StudioJob') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



from urllib.parse import urlparse

from lightning_cloud.login import Auth
from lightning_cloud.openapi import ApiClient, AuthServiceApi, V1LoginRequest
import websocket


class LightningLogsSocketAPI:

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self._auth = Auth()
        self._auth.authenticate()
        self._auth_service = AuthServiceApi(api_client)

    def _get_api_token(self):
        token_resp = self._auth_service.auth_service_login(body=V1LoginRequest(
            username=self._auth.username,
            api_key=self._auth.api_key,
        ))
        return token_resp.token

    @staticmethod
    def _socket_url(host: str, project_id: str, app_id: str, token: str,
                    component: str):
        return (f"wss://{host}/v1/projects/{project_id}/apps/{app_id}/logs?"
                f"token={token}&component={component}&follow=true")

    def create_lightning_logs_socket(
        self,
        project_id: str,
        app_id: str,
        component: str,
        on_message_callback,
        on_error_callback=None,
    ) -> websocket.WebSocketApp:
        """
        Creates and returns WebSocketApp to listen to lightning app logs.

        Usage example synchronous:
            def print_log_msg(ws_app, msg):
                print(msg)

            flow_logs_socket = client.create_lightning_logs_socket('project_id', 'app_id', 'flow', print_log_msg)
            flow_socket.run_forever()

        Usage example asynchronous, multiple components:
            def print_log_msg(ws_app, msg):
                print(msg)

            flow_logs_socket = client.create_lightning_logs_socket('project_id', 'app_id', 'flow', print_log_msg)
            work_logs_socket = client.create_lightning_logs_socket('project_id', 'app_id', 'work_1', print_log_msg)

            flow_logs_thread = Thread(target=flow_logs_socket.run_forever)
            work_logs_thread = Thread(target=work_logs_socket.run_forever)

            flow_logs_thread.start()
            work_logs_thread.start()
            .......

            flow_logs_socket.close()
            work_logs_thread.close()

        Parameters
        ----------
        project_id: str
        app_id: str
        component: str
        on_message_callback: function
            Callback object which is called when received data.
            on_message_callback has 2 arguments.
            The 1st argument is the WebSocketApp object.
            The 2nd argument is utf-8 data received from the server.
        on_error_callback: function
            Callback object which is called when we get error.
            on_error has 2 arguments.
            The 1st argument is this class object.
            The 2nd argument is exception object.

        Returns
        -------
        WebSocketApp of the wanted socket
        """
        _token = self._get_api_token()
        clean_ws_host = urlparse(self.api_client.configuration.host).netloc
        socket_url = self._socket_url(
            host=clean_ws_host,
            project_id=project_id,
            app_id=app_id,
            token=_token,
            component=component,
        )

        return websocket.WebSocketApp(socket_url,
                                      on_message=on_message_callback,
                                      on_error=on_error_callback)



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

from __future__ import absolute_import

import re  # noqa: F401
from typing import TYPE_CHECKING, Any

# python 2 and python 3 compatibility library
import six

from lightning_cloud.openapi.api_client import ApiClient

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class OrganizationsServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def organizations_service_create_org_membership(self, body: 'OrgIdMembershipsBody', org_id: 'str', **kwargs) -> 'V1OrgMembership':  # noqa: E501
        """organizations_service_create_org_membership  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_create_org_membership(body, org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param OrgIdMembershipsBody body: (required)
        :param str org_id: (required)
        :return: V1OrgMembership
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_create_org_membership_with_http_info(body, org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_create_org_membership_with_http_info(body, org_id, **kwargs)  # noqa: E501
            return data

    def organizations_service_create_org_membership_with_http_info(self, body: 'OrgIdMembershipsBody', org_id: 'str', **kwargs) -> 'V1OrgMembership':  # noqa: E501
        """organizations_service_create_org_membership  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_create_org_membership_with_http_info(body, org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param OrgIdMembershipsBody body: (required)
        :param str org_id: (required)
        :return: V1OrgMembership
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_create_org_membership" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `organizations_service_create_org_membership`")  # noqa: E501
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `organizations_service_create_org_membership`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/memberships', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1OrgMembership',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_create_org_membership_role_binding(self, body: 'UserIdMembershiprolebindingsBody', org_id: 'str', user_id: 'str', **kwargs) -> 'V1OrgMembershipRoleBinding':  # noqa: E501
        """organizations_service_create_org_membership_role_binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_create_org_membership_role_binding(body, org_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserIdMembershiprolebindingsBody body: (required)
        :param str org_id: (required)
        :param str user_id: (required)
        :return: V1OrgMembershipRoleBinding
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_create_org_membership_role_binding_with_http_info(body, org_id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_create_org_membership_role_binding_with_http_info(body, org_id, user_id, **kwargs)  # noqa: E501
            return data

    def organizations_service_create_org_membership_role_binding_with_http_info(self, body: 'UserIdMembershiprolebindingsBody', org_id: 'str', user_id: 'str', **kwargs) -> 'V1OrgMembershipRoleBinding':  # noqa: E501
        """organizations_service_create_org_membership_role_binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_create_org_membership_role_binding_with_http_info(body, org_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserIdMembershiprolebindingsBody body: (required)
        :param str org_id: (required)
        :param str user_id: (required)
        :return: V1OrgMembershipRoleBinding
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'org_id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_create_org_membership_role_binding" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `organizations_service_create_org_membership_role_binding`")  # noqa: E501
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `organizations_service_create_org_membership_role_binding`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `organizations_service_create_org_membership_role_binding`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/memberships/{userId}/membershiprolebindings', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1OrgMembershipRoleBinding',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_create_org_role(self, body: 'OrgIdRolesBody', org_id: 'str', **kwargs) -> 'V1OrgRole':  # noqa: E501
        """organizations_service_create_org_role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_create_org_role(body, org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param OrgIdRolesBody body: (required)
        :param str org_id: (required)
        :return: V1OrgRole
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_create_org_role_with_http_info(body, org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_create_org_role_with_http_info(body, org_id, **kwargs)  # noqa: E501
            return data

    def organizations_service_create_org_role_with_http_info(self, body: 'OrgIdRolesBody', org_id: 'str', **kwargs) -> 'V1OrgRole':  # noqa: E501
        """organizations_service_create_org_role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_create_org_role_with_http_info(body, org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param OrgIdRolesBody body: (required)
        :param str org_id: (required)
        :return: V1OrgRole
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_create_org_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `organizations_service_create_org_role`")  # noqa: E501
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `organizations_service_create_org_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/roles', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1OrgRole',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_create_organization(self, body: 'V1CreateOrganizationRequest', **kwargs) -> 'V1Organization':  # noqa: E501
        """organizations_service_create_organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_create_organization(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1CreateOrganizationRequest body: (required)
        :return: V1Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_create_organization_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_create_organization_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def organizations_service_create_organization_with_http_info(self, body: 'V1CreateOrganizationRequest', **kwargs) -> 'V1Organization':  # noqa: E501
        """organizations_service_create_organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_create_organization_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1CreateOrganizationRequest body: (required)
        :return: V1Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_create_organization" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `organizations_service_create_organization`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1Organization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_delete_org_membership_role_binding(self, org_id: 'str', user_id: 'str', role_id: 'str', **kwargs) -> 'V1DeleteOrgMembershipRoleBindingResponse':  # noqa: E501
        """organizations_service_delete_org_membership_role_binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_delete_org_membership_role_binding(org_id, user_id, role_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param str user_id: (required)
        :param str role_id: (required)
        :return: V1DeleteOrgMembershipRoleBindingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_delete_org_membership_role_binding_with_http_info(org_id, user_id, role_id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_delete_org_membership_role_binding_with_http_info(org_id, user_id, role_id, **kwargs)  # noqa: E501
            return data

    def organizations_service_delete_org_membership_role_binding_with_http_info(self, org_id: 'str', user_id: 'str', role_id: 'str', **kwargs) -> 'V1DeleteOrgMembershipRoleBindingResponse':  # noqa: E501
        """organizations_service_delete_org_membership_role_binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_delete_org_membership_role_binding_with_http_info(org_id, user_id, role_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param str user_id: (required)
        :param str role_id: (required)
        :return: V1DeleteOrgMembershipRoleBindingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id', 'user_id', 'role_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_delete_org_membership_role_binding" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `organizations_service_delete_org_membership_role_binding`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `organizations_service_delete_org_membership_role_binding`")  # noqa: E501
        # verify the required parameter 'role_id' is set
        if ('role_id' not in params or
                params['role_id'] is None):
            raise ValueError("Missing the required parameter `role_id` when calling `organizations_service_delete_org_membership_role_binding`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501
        if 'role_id' in params:
            path_params['roleId'] = params['role_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/memberships/{userId}/membershiprolebindings/{roleId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteOrgMembershipRoleBindingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_delete_org_project_membership(self, org_id: 'str', user_id: 'str', **kwargs) -> 'V1DeleteOrgMembershipResponse':  # noqa: E501
        """organizations_service_delete_org_project_membership  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_delete_org_project_membership(org_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param str user_id: (required)
        :return: V1DeleteOrgMembershipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_delete_org_project_membership_with_http_info(org_id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_delete_org_project_membership_with_http_info(org_id, user_id, **kwargs)  # noqa: E501
            return data

    def organizations_service_delete_org_project_membership_with_http_info(self, org_id: 'str', user_id: 'str', **kwargs) -> 'V1DeleteOrgMembershipResponse':  # noqa: E501
        """organizations_service_delete_org_project_membership  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_delete_org_project_membership_with_http_info(org_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param str user_id: (required)
        :return: V1DeleteOrgMembershipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_delete_org_project_membership" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `organizations_service_delete_org_project_membership`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `organizations_service_delete_org_project_membership`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/memberships/{userId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteOrgMembershipResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_delete_org_role(self, org_id: 'str', id: 'str', **kwargs) -> 'V1DeleteOrgRoleResponse':  # noqa: E501
        """organizations_service_delete_org_role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_delete_org_role(org_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param str id: (required)
        :return: V1DeleteOrgRoleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_delete_org_role_with_http_info(org_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_delete_org_role_with_http_info(org_id, id, **kwargs)  # noqa: E501
            return data

    def organizations_service_delete_org_role_with_http_info(self, org_id: 'str', id: 'str', **kwargs) -> 'V1DeleteOrgRoleResponse':  # noqa: E501
        """organizations_service_delete_org_role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_delete_org_role_with_http_info(org_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param str id: (required)
        :return: V1DeleteOrgRoleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_delete_org_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `organizations_service_delete_org_role`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `organizations_service_delete_org_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/roles/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteOrgRoleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_delete_organization(self, id: 'str', **kwargs) -> 'V1DeleteOrganizationResponse':  # noqa: E501
        """DeleteOrganization deletes the organization with the given ID.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_delete_organization(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1DeleteOrganizationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_delete_organization_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_delete_organization_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def organizations_service_delete_organization_with_http_info(self, id: 'str', **kwargs) -> 'V1DeleteOrganizationResponse':  # noqa: E501
        """DeleteOrganization deletes the organization with the given ID.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_delete_organization_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1DeleteOrganizationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_delete_organization" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `organizations_service_delete_organization`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteOrganizationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_get_org_role(self, org_id: 'str', id: 'str', **kwargs) -> 'V1OrgRole':  # noqa: E501
        """organizations_service_get_org_role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_get_org_role(org_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param str id: (required)
        :return: V1OrgRole
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_get_org_role_with_http_info(org_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_get_org_role_with_http_info(org_id, id, **kwargs)  # noqa: E501
            return data

    def organizations_service_get_org_role_with_http_info(self, org_id: 'str', id: 'str', **kwargs) -> 'V1OrgRole':  # noqa: E501
        """organizations_service_get_org_role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_get_org_role_with_http_info(org_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param str id: (required)
        :return: V1OrgRole
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_get_org_role" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `organizations_service_get_org_role`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `organizations_service_get_org_role`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/roles/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1OrgRole',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_get_organization(self, id: 'str', **kwargs) -> 'V1Organization':  # noqa: E501
        """GetOrganization returns the organization with the given ID.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_get_organization(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str name:
        :return: V1Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_get_organization_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_get_organization_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def organizations_service_get_organization_with_http_info(self, id: 'str', **kwargs) -> 'V1Organization':  # noqa: E501
        """GetOrganization returns the organization with the given ID.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_get_organization_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str name:
        :return: V1Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_get_organization" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `organizations_service_get_organization`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1Organization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_list_org_members(self, org_id: 'str', **kwargs) -> 'V1ListOrgMembersResponse':  # noqa: E501
        """organizations_service_list_org_members  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_list_org_members(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param bool include_guests:
        :return: V1ListOrgMembersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_list_org_members_with_http_info(org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_list_org_members_with_http_info(org_id, **kwargs)  # noqa: E501
            return data

    def organizations_service_list_org_members_with_http_info(self, org_id: 'str', **kwargs) -> 'V1ListOrgMembersResponse':  # noqa: E501
        """organizations_service_list_org_members  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_list_org_members_with_http_info(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param bool include_guests:
        :return: V1ListOrgMembersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id', 'include_guests']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_list_org_members" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `organizations_service_list_org_members`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []
        if 'include_guests' in params:
            query_params.append(('includeGuests', params['include_guests']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/members', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListOrgMembersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_list_org_membership_role_bindings(self, org_id: 'str', user_id: 'str', **kwargs) -> 'V1ListOrgMembershipRoleBindingResponse':  # noqa: E501
        """Org membership role binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_list_org_membership_role_bindings(org_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param str user_id: (required)
        :return: V1ListOrgMembershipRoleBindingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_list_org_membership_role_bindings_with_http_info(org_id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_list_org_membership_role_bindings_with_http_info(org_id, user_id, **kwargs)  # noqa: E501
            return data

    def organizations_service_list_org_membership_role_bindings_with_http_info(self, org_id: 'str', user_id: 'str', **kwargs) -> 'V1ListOrgMembershipRoleBindingResponse':  # noqa: E501
        """Org membership role binding  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_list_org_membership_role_bindings_with_http_info(org_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param str user_id: (required)
        :return: V1ListOrgMembershipRoleBindingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_list_org_membership_role_bindings" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `organizations_service_list_org_membership_role_bindings`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `organizations_service_list_org_membership_role_bindings`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/memberships/{userId}/membershiprolebindings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListOrgMembershipRoleBindingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_list_org_memberships(self, org_id: 'str', **kwargs) -> 'V1ListOrgMembershipsResponse':  # noqa: E501
        """Org membership management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_list_org_memberships(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :return: V1ListOrgMembershipsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_list_org_memberships_with_http_info(org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_list_org_memberships_with_http_info(org_id, **kwargs)  # noqa: E501
            return data

    def organizations_service_list_org_memberships_with_http_info(self, org_id: 'str', **kwargs) -> 'V1ListOrgMembershipsResponse':  # noqa: E501
        """Org membership management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_list_org_memberships_with_http_info(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :return: V1ListOrgMembershipsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_list_org_memberships" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `organizations_service_list_org_memberships`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/memberships', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListOrgMembershipsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_list_org_roles(self, org_id: 'str', **kwargs) -> 'V1ListOrgRolesResponse':  # noqa: E501
        """Role management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_list_org_roles(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :return: V1ListOrgRolesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_list_org_roles_with_http_info(org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_list_org_roles_with_http_info(org_id, **kwargs)  # noqa: E501
            return data

    def organizations_service_list_org_roles_with_http_info(self, org_id: 'str', **kwargs) -> 'V1ListOrgRolesResponse':  # noqa: E501
        """Role management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_list_org_roles_with_http_info(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :return: V1ListOrgRolesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_list_org_roles" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `organizations_service_list_org_roles`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/roles', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListOrgRolesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_list_organizations(self, **kwargs) -> 'V1ListOrganizationsResponse':  # noqa: E501
        """TODO: probably a merge with user search API and have a single API to search for anything rpc SearchOrganizations(SearchOrganizationsRequest) returns (SearchOrganizationsResponse) {   option (google.api.http) = {     get: \"/v1/orgs/search\"   }; };  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_list_organizations(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str role_name:
        :return: V1ListOrganizationsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_list_organizations_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_list_organizations_with_http_info(**kwargs)  # noqa: E501
            return data

    def organizations_service_list_organizations_with_http_info(self, **kwargs) -> 'V1ListOrganizationsResponse':  # noqa: E501
        """TODO: probably a merge with user search API and have a single API to search for anything rpc SearchOrganizations(SearchOrganizationsRequest) returns (SearchOrganizationsResponse) {   option (google.api.http) = {     get: \"/v1/orgs/search\"   }; };  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_list_organizations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str role_name:
        :return: V1ListOrganizationsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['role_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_list_organizations" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'role_name' in params:
            query_params.append(('roleName', params['role_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListOrganizationsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def organizations_service_update_organization(self, body: 'OrgsIdBody', id: 'str', **kwargs) -> 'V1Organization':  # noqa: E501
        """Update organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_update_organization(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param OrgsIdBody body: (required)
        :param str id: (required)
        :return: V1Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.organizations_service_update_organization_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.organizations_service_update_organization_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def organizations_service_update_organization_with_http_info(self, body: 'OrgsIdBody', id: 'str', **kwargs) -> 'V1Organization':  # noqa: E501
        """Update organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.organizations_service_update_organization_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param OrgsIdBody body: (required)
        :param str id: (required)
        :return: V1Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method organizations_service_update_organization" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `organizations_service_update_organization`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `organizations_service_update_organization`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1Organization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1LightningRun(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_entrypoint_file': 'str',
        'cloudspace_id': 'str',
        'cluster_id': 'str',
        'created_at': 'datetime',
        'dependency_cache_key': 'str',
        'description': 'str',
        'enable_app_server': 'bool',
        'env': 'list[V1EnvVar]',
        'flow_servers': 'list[V1Flowserver]',
        'id': 'str',
        'image_id': 'str',
        'image_spec': 'V1ImageSpec',
        'is_headless': 'bool',
        'is_published': 'bool',
        'network_config': 'list[V1NetworkConfig]',
        'parent_id': 'str',
        'project_id': 'str',
        'published_at': 'datetime',
        'should_mount_cloudspace_content': 'bool',
        'source_code_url': 'str',
        'source_upload_url': 'str',
        'user_id': 'str',
        'user_requested_flow_compute_config': 'V1UserRequestedFlowComputeConfig',
        'version': 'str',
        'works': 'list[V1Work]'
    }

    attribute_map = {
        'app_entrypoint_file': 'appEntrypointFile',
        'cloudspace_id': 'cloudspaceId',
        'cluster_id': 'clusterId',
        'created_at': 'createdAt',
        'dependency_cache_key': 'dependencyCacheKey',
        'description': 'description',
        'enable_app_server': 'enableAppServer',
        'env': 'env',
        'flow_servers': 'flowServers',
        'id': 'id',
        'image_id': 'imageId',
        'image_spec': 'imageSpec',
        'is_headless': 'isHeadless',
        'is_published': 'isPublished',
        'network_config': 'networkConfig',
        'parent_id': 'parentId',
        'project_id': 'projectId',
        'published_at': 'publishedAt',
        'should_mount_cloudspace_content': 'shouldMountCloudspaceContent',
        'source_code_url': 'sourceCodeUrl',
        'source_upload_url': 'sourceUploadUrl',
        'user_id': 'userId',
        'user_requested_flow_compute_config': 'userRequestedFlowComputeConfig',
        'version': 'version',
        'works': 'works'
    }

    def __init__(self, app_entrypoint_file: 'str' =None, cloudspace_id: 'str' =None, cluster_id: 'str' =None, created_at: 'datetime' =None, dependency_cache_key: 'str' =None, description: 'str' =None, enable_app_server: 'bool' =None, env: 'list[V1EnvVar]' =None, flow_servers: 'list[V1Flowserver]' =None, id: 'str' =None, image_id: 'str' =None, image_spec: 'V1ImageSpec' =None, is_headless: 'bool' =None, is_published: 'bool' =None, network_config: 'list[V1NetworkConfig]' =None, parent_id: 'str' =None, project_id: 'str' =None, published_at: 'datetime' =None, should_mount_cloudspace_content: 'bool' =None, source_code_url: 'str' =None, source_upload_url: 'str' =None, user_id: 'str' =None, user_requested_flow_compute_config: 'V1UserRequestedFlowComputeConfig' =None, version: 'str' =None, works: 'list[V1Work]' =None):  # noqa: E501
        """V1LightningRun - a model defined in Swagger"""  # noqa: E501
        self._app_entrypoint_file = None
        self._cloudspace_id = None
        self._cluster_id = None
        self._created_at = None
        self._dependency_cache_key = None
        self._description = None
        self._enable_app_server = None
        self._env = None
        self._flow_servers = None
        self._id = None
        self._image_id = None
        self._image_spec = None
        self._is_headless = None
        self._is_published = None
        self._network_config = None
        self._parent_id = None
        self._project_id = None
        self._published_at = None
        self._should_mount_cloudspace_content = None
        self._source_code_url = None
        self._source_upload_url = None
        self._user_id = None
        self._user_requested_flow_compute_config = None
        self._version = None
        self._works = None
        self.discriminator = None
        if app_entrypoint_file is not None:
            self.app_entrypoint_file = app_entrypoint_file
        if cloudspace_id is not None:
            self.cloudspace_id = cloudspace_id
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if created_at is not None:
            self.created_at = created_at
        if dependency_cache_key is not None:
            self.dependency_cache_key = dependency_cache_key
        if description is not None:
            self.description = description
        if enable_app_server is not None:
            self.enable_app_server = enable_app_server
        if env is not None:
            self.env = env
        if flow_servers is not None:
            self.flow_servers = flow_servers
        if id is not None:
            self.id = id
        if image_id is not None:
            self.image_id = image_id
        if image_spec is not None:
            self.image_spec = image_spec
        if is_headless is not None:
            self.is_headless = is_headless
        if is_published is not None:
            self.is_published = is_published
        if network_config is not None:
            self.network_config = network_config
        if parent_id is not None:
            self.parent_id = parent_id
        if project_id is not None:
            self.project_id = project_id
        if published_at is not None:
            self.published_at = published_at
        if should_mount_cloudspace_content is not None:
            self.should_mount_cloudspace_content = should_mount_cloudspace_content
        if source_code_url is not None:
            self.source_code_url = source_code_url
        if source_upload_url is not None:
            self.source_upload_url = source_upload_url
        if user_id is not None:
            self.user_id = user_id
        if user_requested_flow_compute_config is not None:
            self.user_requested_flow_compute_config = user_requested_flow_compute_config
        if version is not None:
            self.version = version
        if works is not None:
            self.works = works

    @property
    def app_entrypoint_file(self) -> 'str':
        """Gets the app_entrypoint_file of this V1LightningRun.  # noqa: E501


        :return: The app_entrypoint_file of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._app_entrypoint_file

    @app_entrypoint_file.setter
    def app_entrypoint_file(self, app_entrypoint_file: 'str'):
        """Sets the app_entrypoint_file of this V1LightningRun.


        :param app_entrypoint_file: The app_entrypoint_file of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._app_entrypoint_file = app_entrypoint_file

    @property
    def cloudspace_id(self) -> 'str':
        """Gets the cloudspace_id of this V1LightningRun.  # noqa: E501


        :return: The cloudspace_id of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._cloudspace_id

    @cloudspace_id.setter
    def cloudspace_id(self, cloudspace_id: 'str'):
        """Sets the cloudspace_id of this V1LightningRun.


        :param cloudspace_id: The cloudspace_id of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._cloudspace_id = cloudspace_id

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this V1LightningRun.  # noqa: E501


        :return: The cluster_id of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this V1LightningRun.


        :param cluster_id: The cluster_id of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def created_at(self) -> 'datetime':
        """Gets the created_at of this V1LightningRun.  # noqa: E501


        :return: The created_at of this V1LightningRun.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at: 'datetime'):
        """Sets the created_at of this V1LightningRun.


        :param created_at: The created_at of this V1LightningRun.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def dependency_cache_key(self) -> 'str':
        """Gets the dependency_cache_key of this V1LightningRun.  # noqa: E501


        :return: The dependency_cache_key of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._dependency_cache_key

    @dependency_cache_key.setter
    def dependency_cache_key(self, dependency_cache_key: 'str'):
        """Sets the dependency_cache_key of this V1LightningRun.


        :param dependency_cache_key: The dependency_cache_key of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._dependency_cache_key = dependency_cache_key

    @property
    def description(self) -> 'str':
        """Gets the description of this V1LightningRun.  # noqa: E501


        :return: The description of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: 'str'):
        """Sets the description of this V1LightningRun.


        :param description: The description of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def enable_app_server(self) -> 'bool':
        """Gets the enable_app_server of this V1LightningRun.  # noqa: E501


        :return: The enable_app_server of this V1LightningRun.  # noqa: E501
        :rtype: bool
        """
        return self._enable_app_server

    @enable_app_server.setter
    def enable_app_server(self, enable_app_server: 'bool'):
        """Sets the enable_app_server of this V1LightningRun.


        :param enable_app_server: The enable_app_server of this V1LightningRun.  # noqa: E501
        :type: bool
        """

        self._enable_app_server = enable_app_server

    @property
    def env(self) -> 'list[V1EnvVar]':
        """Gets the env of this V1LightningRun.  # noqa: E501


        :return: The env of this V1LightningRun.  # noqa: E501
        :rtype: list[V1EnvVar]
        """
        return self._env

    @env.setter
    def env(self, env: 'list[V1EnvVar]'):
        """Sets the env of this V1LightningRun.


        :param env: The env of this V1LightningRun.  # noqa: E501
        :type: list[V1EnvVar]
        """

        self._env = env

    @property
    def flow_servers(self) -> 'list[V1Flowserver]':
        """Gets the flow_servers of this V1LightningRun.  # noqa: E501


        :return: The flow_servers of this V1LightningRun.  # noqa: E501
        :rtype: list[V1Flowserver]
        """
        return self._flow_servers

    @flow_servers.setter
    def flow_servers(self, flow_servers: 'list[V1Flowserver]'):
        """Sets the flow_servers of this V1LightningRun.


        :param flow_servers: The flow_servers of this V1LightningRun.  # noqa: E501
        :type: list[V1Flowserver]
        """

        self._flow_servers = flow_servers

    @property
    def id(self) -> 'str':
        """Gets the id of this V1LightningRun.  # noqa: E501


        :return: The id of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1LightningRun.


        :param id: The id of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def image_id(self) -> 'str':
        """Gets the image_id of this V1LightningRun.  # noqa: E501


        :return: The image_id of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id: 'str'):
        """Sets the image_id of this V1LightningRun.


        :param image_id: The image_id of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._image_id = image_id

    @property
    def image_spec(self) -> 'V1ImageSpec':
        """Gets the image_spec of this V1LightningRun.  # noqa: E501


        :return: The image_spec of this V1LightningRun.  # noqa: E501
        :rtype: V1ImageSpec
        """
        return self._image_spec

    @image_spec.setter
    def image_spec(self, image_spec: 'V1ImageSpec'):
        """Sets the image_spec of this V1LightningRun.


        :param image_spec: The image_spec of this V1LightningRun.  # noqa: E501
        :type: V1ImageSpec
        """

        self._image_spec = image_spec

    @property
    def is_headless(self) -> 'bool':
        """Gets the is_headless of this V1LightningRun.  # noqa: E501


        :return: The is_headless of this V1LightningRun.  # noqa: E501
        :rtype: bool
        """
        return self._is_headless

    @is_headless.setter
    def is_headless(self, is_headless: 'bool'):
        """Sets the is_headless of this V1LightningRun.


        :param is_headless: The is_headless of this V1LightningRun.  # noqa: E501
        :type: bool
        """

        self._is_headless = is_headless

    @property
    def is_published(self) -> 'bool':
        """Gets the is_published of this V1LightningRun.  # noqa: E501


        :return: The is_published of this V1LightningRun.  # noqa: E501
        :rtype: bool
        """
        return self._is_published

    @is_published.setter
    def is_published(self, is_published: 'bool'):
        """Sets the is_published of this V1LightningRun.


        :param is_published: The is_published of this V1LightningRun.  # noqa: E501
        :type: bool
        """

        self._is_published = is_published

    @property
    def network_config(self) -> 'list[V1NetworkConfig]':
        """Gets the network_config of this V1LightningRun.  # noqa: E501


        :return: The network_config of this V1LightningRun.  # noqa: E501
        :rtype: list[V1NetworkConfig]
        """
        return self._network_config

    @network_config.setter
    def network_config(self, network_config: 'list[V1NetworkConfig]'):
        """Sets the network_config of this V1LightningRun.


        :param network_config: The network_config of this V1LightningRun.  # noqa: E501
        :type: list[V1NetworkConfig]
        """

        self._network_config = network_config

    @property
    def parent_id(self) -> 'str':
        """Gets the parent_id of this V1LightningRun.  # noqa: E501


        :return: The parent_id of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id: 'str'):
        """Sets the parent_id of this V1LightningRun.


        :param parent_id: The parent_id of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1LightningRun.  # noqa: E501


        :return: The project_id of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1LightningRun.


        :param project_id: The project_id of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def published_at(self) -> 'datetime':
        """Gets the published_at of this V1LightningRun.  # noqa: E501


        :return: The published_at of this V1LightningRun.  # noqa: E501
        :rtype: datetime
        """
        return self._published_at

    @published_at.setter
    def published_at(self, published_at: 'datetime'):
        """Sets the published_at of this V1LightningRun.


        :param published_at: The published_at of this V1LightningRun.  # noqa: E501
        :type: datetime
        """

        self._published_at = published_at

    @property
    def should_mount_cloudspace_content(self) -> 'bool':
        """Gets the should_mount_cloudspace_content of this V1LightningRun.  # noqa: E501


        :return: The should_mount_cloudspace_content of this V1LightningRun.  # noqa: E501
        :rtype: bool
        """
        return self._should_mount_cloudspace_content

    @should_mount_cloudspace_content.setter
    def should_mount_cloudspace_content(self, should_mount_cloudspace_content: 'bool'):
        """Sets the should_mount_cloudspace_content of this V1LightningRun.


        :param should_mount_cloudspace_content: The should_mount_cloudspace_content of this V1LightningRun.  # noqa: E501
        :type: bool
        """

        self._should_mount_cloudspace_content = should_mount_cloudspace_content

    @property
    def source_code_url(self) -> 'str':
        """Gets the source_code_url of this V1LightningRun.  # noqa: E501


        :return: The source_code_url of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._source_code_url

    @source_code_url.setter
    def source_code_url(self, source_code_url: 'str'):
        """Sets the source_code_url of this V1LightningRun.


        :param source_code_url: The source_code_url of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._source_code_url = source_code_url

    @property
    def source_upload_url(self) -> 'str':
        """Gets the source_upload_url of this V1LightningRun.  # noqa: E501

        url to which the source code can be uploaded - needed only if local source and not github. Client will send the request that indicates that it needs to upload the source to s3, controlplane will fill this url and response will be sent back to the client. Client will then use this url to upload the source to s3.  # noqa: E501

        :return: The source_upload_url of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._source_upload_url

    @source_upload_url.setter
    def source_upload_url(self, source_upload_url: 'str'):
        """Sets the source_upload_url of this V1LightningRun.

        url to which the source code can be uploaded - needed only if local source and not github. Client will send the request that indicates that it needs to upload the source to s3, controlplane will fill this url and response will be sent back to the client. Client will then use this url to upload the source to s3.  # noqa: E501

        :param source_upload_url: The source_upload_url of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._source_upload_url = source_upload_url

    @property
    def user_id(self) -> 'str':
        """Gets the user_id of this V1LightningRun.  # noqa: E501


        :return: The user_id of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: 'str'):
        """Sets the user_id of this V1LightningRun.


        :param user_id: The user_id of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_requested_flow_compute_config(self) -> 'V1UserRequestedFlowComputeConfig':
        """Gets the user_requested_flow_compute_config of this V1LightningRun.  # noqa: E501


        :return: The user_requested_flow_compute_config of this V1LightningRun.  # noqa: E501
        :rtype: V1UserRequestedFlowComputeConfig
        """
        return self._user_requested_flow_compute_config

    @user_requested_flow_compute_config.setter
    def user_requested_flow_compute_config(self, user_requested_flow_compute_config: 'V1UserRequestedFlowComputeConfig'):
        """Sets the user_requested_flow_compute_config of this V1LightningRun.


        :param user_requested_flow_compute_config: The user_requested_flow_compute_config of this V1LightningRun.  # noqa: E501
        :type: V1UserRequestedFlowComputeConfig
        """

        self._user_requested_flow_compute_config = user_requested_flow_compute_config

    @property
    def version(self) -> 'str':
        """Gets the version of this V1LightningRun.  # noqa: E501


        :return: The version of this V1LightningRun.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version: 'str'):
        """Sets the version of this V1LightningRun.


        :param version: The version of this V1LightningRun.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def works(self) -> 'list[V1Work]':
        """Gets the works of this V1LightningRun.  # noqa: E501


        :return: The works of this V1LightningRun.  # noqa: E501
        :rtype: list[V1Work]
        """
        return self._works

    @works.setter
    def works(self, works: 'list[V1Work]'):
        """Sets the works of this V1LightningRun.


        :param works: The works of this V1LightningRun.  # noqa: E501
        :type: list[V1Work]
        """

        self._works = works

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1LightningRun, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1LightningRun') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1LightningRun):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1LightningRun') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1ClusterCapacityReservation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cloud_provider_capacity_reservation_id': 'str',
        'cluster_id': 'str',
        'id': 'str',
        'match_pattern': 'str',
        'project_id': 'str'
    }

    attribute_map = {
        'cloud_provider_capacity_reservation_id': 'cloudProviderCapacityReservationId',
        'cluster_id': 'clusterId',
        'id': 'id',
        'match_pattern': 'matchPattern',
        'project_id': 'projectId'
    }

    def __init__(self, cloud_provider_capacity_reservation_id: 'str' =None, cluster_id: 'str' =None, id: 'str' =None, match_pattern: 'str' =None, project_id: 'str' =None):  # noqa: E501
        """V1ClusterCapacityReservation - a model defined in Swagger"""  # noqa: E501
        self._cloud_provider_capacity_reservation_id = None
        self._cluster_id = None
        self._id = None
        self._match_pattern = None
        self._project_id = None
        self.discriminator = None
        if cloud_provider_capacity_reservation_id is not None:
            self.cloud_provider_capacity_reservation_id = cloud_provider_capacity_reservation_id
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if id is not None:
            self.id = id
        if match_pattern is not None:
            self.match_pattern = match_pattern
        if project_id is not None:
            self.project_id = project_id

    @property
    def cloud_provider_capacity_reservation_id(self) -> 'str':
        """Gets the cloud_provider_capacity_reservation_id of this V1ClusterCapacityReservation.  # noqa: E501


        :return: The cloud_provider_capacity_reservation_id of this V1ClusterCapacityReservation.  # noqa: E501
        :rtype: str
        """
        return self._cloud_provider_capacity_reservation_id

    @cloud_provider_capacity_reservation_id.setter
    def cloud_provider_capacity_reservation_id(self, cloud_provider_capacity_reservation_id: 'str'):
        """Sets the cloud_provider_capacity_reservation_id of this V1ClusterCapacityReservation.


        :param cloud_provider_capacity_reservation_id: The cloud_provider_capacity_reservation_id of this V1ClusterCapacityReservation.  # noqa: E501
        :type: str
        """

        self._cloud_provider_capacity_reservation_id = cloud_provider_capacity_reservation_id

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this V1ClusterCapacityReservation.  # noqa: E501


        :return: The cluster_id of this V1ClusterCapacityReservation.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this V1ClusterCapacityReservation.


        :param cluster_id: The cluster_id of this V1ClusterCapacityReservation.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def id(self) -> 'str':
        """Gets the id of this V1ClusterCapacityReservation.  # noqa: E501


        :return: The id of this V1ClusterCapacityReservation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1ClusterCapacityReservation.


        :param id: The id of this V1ClusterCapacityReservation.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def match_pattern(self) -> 'str':
        """Gets the match_pattern of this V1ClusterCapacityReservation.  # noqa: E501


        :return: The match_pattern of this V1ClusterCapacityReservation.  # noqa: E501
        :rtype: str
        """
        return self._match_pattern

    @match_pattern.setter
    def match_pattern(self, match_pattern: 'str'):
        """Sets the match_pattern of this V1ClusterCapacityReservation.


        :param match_pattern: The match_pattern of this V1ClusterCapacityReservation.  # noqa: E501
        :type: str
        """

        self._match_pattern = match_pattern

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1ClusterCapacityReservation.  # noqa: E501


        :return: The project_id of this V1ClusterCapacityReservation.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1ClusterCapacityReservation.


        :param project_id: The project_id of this V1ClusterCapacityReservation.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ClusterCapacityReservation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ClusterCapacityReservation') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ClusterCapacityReservation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1ClusterCapacityReservation') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class IdExecuteBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'command': 'str',
        'detached': 'bool',
        'session_name': 'str'
    }

    attribute_map = {
        'command': 'command',
        'detached': 'detached',
        'session_name': 'sessionName'
    }

    def __init__(self, command: 'str' =None, detached: 'bool' =None, session_name: 'str' =None):  # noqa: E501
        """IdExecuteBody - a model defined in Swagger"""  # noqa: E501
        self._command = None
        self._detached = None
        self._session_name = None
        self.discriminator = None
        if command is not None:
            self.command = command
        if detached is not None:
            self.detached = detached
        if session_name is not None:
            self.session_name = session_name

    @property
    def command(self) -> 'str':
        """Gets the command of this IdExecuteBody.  # noqa: E501


        :return: The command of this IdExecuteBody.  # noqa: E501
        :rtype: str
        """
        return self._command

    @command.setter
    def command(self, command: 'str'):
        """Sets the command of this IdExecuteBody.


        :param command: The command of this IdExecuteBody.  # noqa: E501
        :type: str
        """

        self._command = command

    @property
    def detached(self) -> 'bool':
        """Gets the detached of this IdExecuteBody.  # noqa: E501


        :return: The detached of this IdExecuteBody.  # noqa: E501
        :rtype: bool
        """
        return self._detached

    @detached.setter
    def detached(self, detached: 'bool'):
        """Sets the detached of this IdExecuteBody.


        :param detached: The detached of this IdExecuteBody.  # noqa: E501
        :type: bool
        """

        self._detached = detached

    @property
    def session_name(self) -> 'str':
        """Gets the session_name of this IdExecuteBody.  # noqa: E501


        :return: The session_name of this IdExecuteBody.  # noqa: E501
        :rtype: str
        """
        return self._session_name

    @session_name.setter
    def session_name(self, session_name: 'str'):
        """Sets the session_name of this IdExecuteBody.


        :param session_name: The session_name of this IdExecuteBody.  # noqa: E501
        :type: str
        """

        self._session_name = session_name

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IdExecuteBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'IdExecuteBody') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, IdExecuteBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'IdExecuteBody') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



import click


@click.group()
def main():
    pass


@main.command()
def login():
    """Authorize the CLI to access Grid AI resources for a particular user.
    Use login command to force authenticate,
    a web browser will open to complete the authentication.
    """
    from lightning_cloud.login import Auth  # local to avoid circular import

    auth = Auth()
    auth.clear()
    auth._run_server()


@main.command()
def logout():
    """Logout from LightningCloud"""
    from lightning_cloud.login import Auth  # local to avoid circular import

    Auth.clear()



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1ComputeConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu_image_override': 'str',
        'gpu_image_override': 'str',
        'id': 'str',
        'instance_type': 'str',
        'resources': 'V1Resources',
        'shm_size_mb': 'int'
    }

    attribute_map = {
        'cpu_image_override': 'cpuImageOverride',
        'gpu_image_override': 'gpuImageOverride',
        'id': 'id',
        'instance_type': 'instanceType',
        'resources': 'resources',
        'shm_size_mb': 'shmSizeMb'
    }

    def __init__(self, cpu_image_override: 'str' =None, gpu_image_override: 'str' =None, id: 'str' =None, instance_type: 'str' =None, resources: 'V1Resources' =None, shm_size_mb: 'int' =None):  # noqa: E501
        """V1ComputeConfig - a model defined in Swagger"""  # noqa: E501
        self._cpu_image_override = None
        self._gpu_image_override = None
        self._id = None
        self._instance_type = None
        self._resources = None
        self._shm_size_mb = None
        self.discriminator = None
        if cpu_image_override is not None:
            self.cpu_image_override = cpu_image_override
        if gpu_image_override is not None:
            self.gpu_image_override = gpu_image_override
        if id is not None:
            self.id = id
        if instance_type is not None:
            self.instance_type = instance_type
        if resources is not None:
            self.resources = resources
        if shm_size_mb is not None:
            self.shm_size_mb = shm_size_mb

    @property
    def cpu_image_override(self) -> 'str':
        """Gets the cpu_image_override of this V1ComputeConfig.  # noqa: E501

        cpu_image_override is used to specify a custom image used to launch the resource when running on a cpu machine.  # noqa: E501

        :return: The cpu_image_override of this V1ComputeConfig.  # noqa: E501
        :rtype: str
        """
        return self._cpu_image_override

    @cpu_image_override.setter
    def cpu_image_override(self, cpu_image_override: 'str'):
        """Sets the cpu_image_override of this V1ComputeConfig.

        cpu_image_override is used to specify a custom image used to launch the resource when running on a cpu machine.  # noqa: E501

        :param cpu_image_override: The cpu_image_override of this V1ComputeConfig.  # noqa: E501
        :type: str
        """

        self._cpu_image_override = cpu_image_override

    @property
    def gpu_image_override(self) -> 'str':
        """Gets the gpu_image_override of this V1ComputeConfig.  # noqa: E501

        gpu_image_override is used to specify a custom image used to launch the resource when running on a cpu machine.  # noqa: E501

        :return: The gpu_image_override of this V1ComputeConfig.  # noqa: E501
        :rtype: str
        """
        return self._gpu_image_override

    @gpu_image_override.setter
    def gpu_image_override(self, gpu_image_override: 'str'):
        """Sets the gpu_image_override of this V1ComputeConfig.

        gpu_image_override is used to specify a custom image used to launch the resource when running on a cpu machine.  # noqa: E501

        :param gpu_image_override: The gpu_image_override of this V1ComputeConfig.  # noqa: E501
        :type: str
        """

        self._gpu_image_override = gpu_image_override

    @property
    def id(self) -> 'str':
        """Gets the id of this V1ComputeConfig.  # noqa: E501


        :return: The id of this V1ComputeConfig.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1ComputeConfig.


        :param id: The id of this V1ComputeConfig.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def instance_type(self) -> 'str':
        """Gets the instance_type of this V1ComputeConfig.  # noqa: E501


        :return: The instance_type of this V1ComputeConfig.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type: 'str'):
        """Sets the instance_type of this V1ComputeConfig.


        :param instance_type: The instance_type of this V1ComputeConfig.  # noqa: E501
        :type: str
        """

        self._instance_type = instance_type

    @property
    def resources(self) -> 'V1Resources':
        """Gets the resources of this V1ComputeConfig.  # noqa: E501


        :return: The resources of this V1ComputeConfig.  # noqa: E501
        :rtype: V1Resources
        """
        return self._resources

    @resources.setter
    def resources(self, resources: 'V1Resources'):
        """Sets the resources of this V1ComputeConfig.


        :param resources: The resources of this V1ComputeConfig.  # noqa: E501
        :type: V1Resources
        """

        self._resources = resources

    @property
    def shm_size_mb(self) -> 'int':
        """Gets the shm_size_mb of this V1ComputeConfig.  # noqa: E501


        :return: The shm_size_mb of this V1ComputeConfig.  # noqa: E501
        :rtype: int
        """
        return self._shm_size_mb

    @shm_size_mb.setter
    def shm_size_mb(self, shm_size_mb: 'int'):
        """Sets the shm_size_mb of this V1ComputeConfig.


        :param shm_size_mb: The shm_size_mb of this V1ComputeConfig.  # noqa: E501
        :type: int
        """

        self._shm_size_mb = shm_size_mb

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ComputeConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ComputeConfig') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ComputeConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1ComputeConfig') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



import os
from time import sleep, time
from lightning_cloud.openapi import Create, V1AwsDataConnection

def add_s3_connection(bucket_name: str, region: str = "us-east-1", create_timeout: int = 15) -> None:
    """Utility to add a data connection."""
    from lightning_cloud import rest_client

    client = rest_client.LightningClient(retry=False)

    project_id = os.getenv("LIGHTNING_CLOUD_PROJECT_ID")
    cluster_id = os.getenv("LIGHTNING_CLUSTER_ID")

    data_connections = client.data_connection_service_list_data_connections(project_id).data_connections

    if any(d for d in data_connections if d.name == bucket_name):
        return

    body = Create(
        name=bucket_name,
        create_index=True,
        cluster_id=cluster_id,
        aws=V1AwsDataConnection(
            source=f"s3://{bucket_name}",
            region=region
    ))
    client.data_connection_service_create_data_connection(body, project_id)

    # Wait for the filesystem picks up the new data connection
    start = time()

    while not os.path.isdir(f"/teamspace/s3_connections/{bucket_name}") and (time() - start) < create_timeout:
        sleep(1)